/**
 * @file
 * JavaScript to handle Merchant Warrior Payframe integration.
 */
(function ($, Drupal, drupalSettings) {
  "use strict";

  Drupal.behaviors.commerceMerchantWarriorPayframe = {
    attach: function (context, settings) {
      // Ensure this code runs only once per element.
      $(".commerce-merchant-warrior-payframe-form", context).each(function () {
        // Check if this element has already been processed.
        if ($(this).data("processed")) {
          return;
        }

        // Mark this element as processed.
        $(this).data("processed", true);

        var $paymentForm = $(this).closest("form");
        var $accessToken =
          drupalSettings.commerceMerchantWarriorPayframe.accessToken;
        var $submitUrl =
          drupalSettings.commerceMerchantWarriorPayframe.submitUrl;
        var $src = drupalSettings.commerceMerchantWarriorPayframe.src;

        var payframeData = {
          accessToken: $accessToken,
          payframeDivId: "cardData",
          src: $src,
          submitUrl: $submitUrl,
          method: "getPayframeToken",
        };
        var mwPayframe = new payframe(payframeData);

        mwPayframe.mwCallback = function (
          tokenStatus,
          payframeToken,
          payframeKey
        ) {
          processResponseEvent(tokenStatus, payframeToken, payframeKey);
        };

        mwPayframe.deploy();

        function processResponseEvent(tokenStatus, payframeToken, payframeKey) {
          if (tokenStatus === "HAS_TOKEN") {
            $("#merchant-warrior-access-token", $paymentForm).val($accessToken);
            $("#merchant-warrior-payframe-token", $paymentForm).val(
              payframeToken
            );
            $("#merchant-warrior-payframe-key", $paymentForm).val(payframeKey);

            mwPayframe.reset();
            $paymentForm.get(0).submit();
          } else {
            commerceMerchantWarriorPayframeErrorDisplay(
              Drupal.t(
                "An error occurred while submitting the payment to the payment gateway. Please try again."
              )
            );
            mwPayframe.reset();
          }
        }

        $paymentForm.on("submit", function (event) {
          event.preventDefault();
          mwPayframe.submitPayframe();
          return false;
        });

        function commerceMerchantWarriorPayframeErrorDisplay(error_message) {
          $paymentForm
            .find("#payment-errors")
            .html(
              Drupal.theme(
                "commerceMerchantWarriorPayframeError",
                error_message
              )
            );
        }

        $.extend(Drupal.theme, {
          commerceMerchantWarriorPayframeError: function (message) {
            return $('<div class="messages messages--error"></div>').html(
              message
            );
          },
        });
      });
    },
  };
})(jQuery, Drupal, drupalSettings);
