<?php

namespace Drupal\commerce_merchant_warrior\Plugin\rest\resource;

use Drupal\commerce_merchant_warrior\Api\MerchantWarriorApiInterface;
use Drupal\rest\ModifiedResourceResponse;
use Drupal\rest\Plugin\ResourceBase;
use Psr\Log\LoggerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Fetches an access token from Merchant Warrior Direct API.
 *
 * @RestResource(
 *   id = "merchant_warrior_get_access_token_resource",
 *   label = @Translation("Merchant Warrior: Get access token resource"),
 *   uri_paths = {
 *     "canonical" = "/api/merchant-warrior/get-access-token"
 *   }
 * )
 */
class MerchantWarriorGetAccessToken extends ResourceBase {

  /**
   * The Merchant Warrior API client.
   *
   * @var \Drupal\commerce_merchant_warrior\Api\MerchantWarriorApiInterface
   */
  protected MerchantWarriorApiInterface $apiClient;

  /**
   * Constructs a MerchantWarriorGetAccessToken instance.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param array $serializer_formats
   *   The available serialization formats.
   * @param \Psr\Log\LoggerInterface $logger
   *   A logger instance.
   * @param \Drupal\commerce_merchant_warrior\Api\MerchantWarriorApiInterface $api_client
   *   The Merchant Warrior API client.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    $serializer_formats,
    LoggerInterface $logger,
    MerchantWarriorApiInterface $api_client,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $serializer_formats, $logger);

    $this->apiClient = $api_client;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->getParameter('serializer.formats'),
      $container->get('logger.factory')->get('rest'),
      $container->get('commerce_merchant_warrior.api_client'),
    );
  }

  /**
   * Responds to the GET request to get an access token.
   *
   * @return \Drupal\rest\ModifiedResourceResponse
   *   The access token from Merchant Warrior and host URLs for Payframe.
   */
  public function get(): ModifiedResourceResponse {
    return new ModifiedResourceResponse([
      'token' => $this->apiClient->getAccessToken(),
      'payframeSubmitUrl' => $this->apiClient->getPayframeSubmitUrl(),
      'payframeSrcUrl' => $this->apiClient->getPayframeSrcUrl(),
    ], 200);
  }

}
