<?php

namespace Drupal\Tests\commerce_merchant_warrior\Unit\Plugin\rest\resource;

use Drupal\Tests\UnitTestCase;
use Drupal\commerce_merchant_warrior\Api\MerchantWarriorApiInterface;
use Drupal\commerce_merchant_warrior\Plugin\rest\resource\MerchantWarriorGetAccessToken;
use Drupal\rest\ModifiedResourceResponse;
use Psr\Log\LoggerInterface;

/**
 * @coversDefaultClass \Drupal\commerce_merchant_warrior\Plugin\rest\resource\MerchantWarriorGetAccessToken
 */
class MerchantWarriorGetAccessTokenTest extends UnitTestCase {

  /**
   * The API client mock.
   *
   * @var \PHPUnit\Framework\MockObject\MockObject|\Drupal\commerce_merchant_warrior\Api\MerchantWarriorApiInterface
   */
  protected $apiClient;

  /**
   * The logger mock.
   *
   * @var \PHPUnit\Framework\MockObject\MockObject|\Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * The resource instance.
   *
   * @var \Drupal\commerce_merchant_warrior\Plugin\rest\resource\MerchantWarriorGetAccessToken
   */
  protected $resource;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->apiClient = $this->createMock(MerchantWarriorApiInterface::class);
    $this->logger = $this->createMock(LoggerInterface::class);

    $configuration = [];
    $plugin_id = 'merchant_warrior_get_access_token_resource';
    $plugin_definition = [];
    $serializer_formats = ['json'];

    $this->resource = new MerchantWarriorGetAccessToken($configuration, $plugin_id, $plugin_definition, $serializer_formats, $this->logger, $this->apiClient);
  }

  /**
   * Tests the get method.
   */
  public function testGet(): void {
    $expected_response = [
      'token' => 'test_access_token',
      'payframeSubmitUrl' => '',
      'payframeSrcUrl' => '',
    ];
    $this->apiClient->expects($this->once())
      ->method('getAccessToken')
      ->willReturn($expected_response['token']);

    $response = $this->resource->get();
    $this->assertInstanceOf(ModifiedResourceResponse::class, $response);
    $this->assertEquals(200, $response->getStatusCode());
    $this->assertEquals($expected_response, $response->getResponseData());
  }

}
